aboutsummaryrefslogtreecommitdiffstats
path: root/lib/Support/Host.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Support/Host.cpp')
-rw-r--r--lib/Support/Host.cpp8
1 files changed, 7 insertions, 1 deletions
diff --git a/lib/Support/Host.cpp b/lib/Support/Host.cpp
index 42bc342..0e9a62e 100644
--- a/lib/Support/Host.cpp
+++ b/lib/Support/Host.cpp
@@ -357,10 +357,16 @@ StringRef sys::getHostCPUName() {
case 63:
case 69:
case 70:
// Not all Haswell processors support AVX too (such as the Pentium
// versions instead of the i7 versions).
return HasAVX2 ? "core-avx2" : "corei7";
+ // Broadwell:
+ case 61:
+ // Not all Broadwell processors support AVX2 (such as the Pentium
+ // versions instead of the i7 versions).
+ return HasAVX2 ? "broadwell" : "corei7";
+
case 28: // Most 45 nm Intel Atom processors
case 38: // 45 nm Atom Lincroft
case 39: // 32 nm Atom Medfield
@@ -357,10 +357,16 @@ StringRef sys::getHostCPUName() {
case 69:
case 70:
- // Not all Haswell processors support AVX too (such as the Pentium
+ // Not all Haswell processors support AVX2 (such as the Pentium
// versions instead of the i7 versions).
return HasAVX2 ? "core-avx2" : "corei7";